@@ -3,10 +3,11 @@ package Lemonldap::NG::Common::PSGI;
 use 5.10.0;
 use Mouse;
 use JSON;
+use Lemonldap::NG::Common;
 use Lemonldap::NG::Common::PSGI::Constants;
 use Lemonldap::NG::Common::PSGI::Request;
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.3';
 
 our $_json = JSON->new->allow_nonref;
 
@@ -180,7 +181,7 @@ sub sendHtml {
             PORTAL              => $self->portal,
             LINKS => $self->links ? to_json( $self->links ) : '""',
             MENULINKS => $self->menuLinks ? to_json( $self->menuLinks ) : '""',
-            VERSION => $VERSION,
+            VERSION => $Lemonldap::NG::Common::VERSION,
         );
     };
     if ($@) {
